@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -302,11 +302,13 @@ class CommandContainer:
         self.__commands_to_add: List[Tuple[Dict[str, Any], Union[str, None]]] = []
         self.__channels_to_add: List[Tuple[Dict[str, Any], str]] = []
 
-    def __getattr__(self, attr: str) -> CommandObject:
-        try:
-            return self.__dict__["_CommandContainer__commands"][attr]
-        except KeyError:
-            raise AttributeError(attr)
+    def __getattr__(self, attr: str):
+        if attr in self.__commands:
+            logging.getLogger("HWR").warning(
+                "__getattr__ should not be used to retrieve "
+                "commands. Use get_command_object() instead."
+            )
+        return super().__getattribute__(attr)
 
     def get_channel_object(
         self,
@@ -327,7 +329,6 @@ class CommandContainer:
         if channel is None and not optional:
             msg = "%s: Unable to get channel %s" % (self.id, channel_name)
             logging.getLogger("user_level_log").error(msg)
-            # raise Exception(msg)
         return channel
 
     def get_channel_names_list(self) -> List[str]:
