@@ -18,13 +18,8 @@ Example XML::
 
 """
 
-import logging
-
 from ALBAEpsActuator import ALBAEpsActuator
 
-from mxcubecore import BaseHardwareObjects
-from mxcubecore import HardwareRepository as HWR
-
 
 class ALBAFrontEnd(ALBAEpsActuator):
     def init(self):
