@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -42,13 +42,11 @@ except ImportError:
     traceback.print_exc()
     redis_flag = False
 
-from mxcubecore.BaseHardwareObjects import HardwareObject
 from mxcubecore.HardwareObjects.abstract.AbstractVideoDevice import AbstractVideoDevice
 from mxcubecore.utils.conversion import string_types
 from mxcubecore.utils.qt_import import (
     QImage,
     QPixmap,
-    QPoint,
 )
 
 
@@ -463,7 +461,7 @@ class MjpgStreamVideo(AbstractVideoDevice):
         return False
 
     def get_cmd_info(self, cmd, group=None, plugin=None, dest=None):
-        """Returns a dictionary with informations on the queried command.
+        """Returns a dictionary with information on the queried command.
 
         Keyword arguments:
         cmd -- command id number or tuple constant
