@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -30,7 +30,6 @@ from XSDataCommon import (
     XSDataAngle,
     XSDataBoolean,
     XSDataDouble,
-    XSDataFile,
     XSDataFlux,
     XSDataImage,
     XSDataInteger,
@@ -47,13 +46,7 @@ from XSDataMXCuBEv1_4 import (
 )
 
 from mxcubecore import HardwareRepository as HWR
-from mxcubecore.HardwareObjects.abstract.AbstractCharacterisation import (
-    AbstractCharacterisation,
-)
 from mxcubecore.HardwareObjects.EDNACharacterisation import EDNACharacterisation
-from mxcubecore.HardwareObjects.SecureXMLRpcRequestHandler import (
-    SecureXMLRpcRequestHandler,
-)
 from mxcubecore.model import queue_model_enumerables as qme
 from mxcubecore.model import queue_model_objects as qmo
 
@@ -450,7 +443,7 @@ class P11EDNACharacterisation(EDNACharacterisation):
             "======= Characterisation path where to search for images ====%s", path_str
         )
 
-        # NB!: Directories at this point are created elswhere (data_collection_hook)
+        # NB!: Directories at this point are created elsewhere (data_collection_hook)
         # xds_dir at this point already has all the needed substitutions.
         characterisation_dir = path_template.xds_dir
 
