@@ -1,5 +1,5 @@
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -31,12 +31,11 @@ __category__ = "General"
 
 class EMBLCollect(AbstractCollect):
     """Main data collection class. Inherited from AbstractCollect.
-       Collection is done by setting collection parameters and
-       executing collect command
+    Collection is done by setting collection parameters and
+    executing collect command
     """
 
     def __init__(self, name):
-
         AbstractCollect.__init__(self, name)
         self._previous_collect_status = None
         self._actual_collect_status = None
@@ -195,7 +194,7 @@ class EMBLCollect(AbstractCollect):
                 #    in (True, "MeshScan", "XrayCentering")
                 #
 
-            #if self.current_dc_parameters["processing_online"] is False:
+            # if self.current_dc_parameters["processing_online"] is False:
             #    self.cmd_collect_processing(False)
 
             # GB 2018-05-16 : Workaround a fuzzy mesh scan interface of MD3
@@ -287,7 +286,7 @@ class EMBLCollect(AbstractCollect):
             )
 
     def collection_finished(self):
-        """Additionaly sets break bragg if it was previously released"""
+        """Additionally sets break bragg if it was previously released"""
         AbstractCollect.collection_finished(self)
         if (
             self.current_dc_parameters["in_queue"] is False
@@ -344,9 +343,9 @@ class EMBLCollect(AbstractCollect):
 
     def set_helical_pos(self, arg):
         """Sets helical positions
-           8 floats describe:
-             p1AlignmY, p1AlignmZ, p1CentrX, p1CentrY
-             p2AlignmY, p2AlignmZ, p2CentrX, p2CentrY
+        8 floats describe:
+          p1AlignmY, p1AlignmZ, p1CentrX, p1CentrY
+          p2AlignmY, p2AlignmZ, p2CentrX, p2CentrY
         """
         helical_positions = [
             arg["1"]["phiy"],
@@ -381,7 +380,7 @@ class EMBLCollect(AbstractCollect):
     @task
     def _take_crystal_animation(self, animation_filename, duration_sec=1):
         """Rotates sample by 360 and composes a gif file
-           Animation is saved as the fourth snapshot
+        Animation is saved as the fourth snapshot
         """
 
         HWR.beamline.sample_view.save_scene_animation(animation_filename, duration_sec)
@@ -399,14 +398,14 @@ class EMBLCollect(AbstractCollect):
     #     self.cmd_collect_energy(self.get_energy() * 1000)
 
     def set_resolution(self, value):
-         """Sets resolution in A"""
-         if not value:
-             value = self.get_resolution()
-         self.cmd_collect_resolution(value)
+        """Sets resolution in A"""
+        if not value:
+            value = self.get_resolution()
+        self.cmd_collect_resolution(value)
 
     def set_transmission(self, value):
-         """Sets transmission in %"""
-         self.cmd_collect_transmission(value)
+        """Sets transmission in %"""
+        self.cmd_collect_transmission(value)
 
     @task
     def move_motors(self, motor_position_dict):
@@ -435,8 +434,7 @@ class EMBLCollect(AbstractCollect):
         return xds_directory, ""
 
     def get_undulators_gaps(self):
-        """Return triplet with gaps. In our case we have one gap,
-        """
+        """Return triplet with gaps. In our case we have one gap,"""
         und_gaps = {}
         if self.chan_undulator_gap:
             und_gaps = self.chan_undulator_gap.get_value()
