@@ -1,5 +1,5 @@
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -19,11 +19,9 @@
 
 import logging
 from copy import deepcopy
-from datetime import datetime
 
 import gevent
 import numpy
-import tine
 from scipy.interpolate import interp1d
 
 from mxcubecore import HardwareRepository as HWR
@@ -130,7 +128,6 @@ carbon_window_transmission = interp1d(
 
 class EMBLFlux(AbstractFlux):
     def __init__(self, name):
-
         AbstractFlux.__init__(self, name)
 
         self.measured_flux_dict = None
@@ -139,7 +136,7 @@ class EMBLFlux(AbstractFlux):
 
         self.flux_value = 0
         # self.ampl_chan_index = None
-        #self.intensity_ranges = []
+        # self.intensity_ranges = []
         self.intensity_value = None
 
         self.flux_record_status = None
@@ -157,8 +154,7 @@ class EMBLFlux(AbstractFlux):
         self.cmd_set_intens_resolution = None
 
     def init(self):
-        """Reads config xml, initiates all necessary hwobj, channels and cmds
-        """
+        """Reads config xml, initiates all necessary hwobj, channels and cmds"""
         super(EMBLFlux, self).init()
 
         """
@@ -203,7 +199,9 @@ class EMBLFlux(AbstractFlux):
         self.connect(HWR.beamline.beam, "beamInfoChanged", self.beam_info_changed)
 
         self.connect(
-            HWR.beamline.beam.aperture, "diameterIndexChanged", self.aperture_diameter_changed
+            HWR.beamline.beam.aperture,
+            "diameterIndexChanged",
+            self.aperture_diameter_changed,
         )
 
         if HWR.beamline.beam.definer is not None:
