@@ -1,5 +1,5 @@
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -49,12 +49,11 @@ __category__ = "General"
 
 
 class EMBLMachineInfo(HardwareObject):
-    """Displays actual information about the beamline
-    """
+    """Displays actual information about the beamline"""
 
     def __init__(self, name):
         """OrderedDict is used to have a sorted items for display
-           and directory like access when updating values
+        and directory like access when updating values
         """
 
         HardwareObject.__init__(self, name)
@@ -119,7 +118,6 @@ class EMBLMachineInfo(HardwareObject):
         self.chan_sc_dewar_overflow_alarm = None
 
     def init(self):
-
         self.update_interval = int(self.get_property("updateIntervalS"))
         self.limits_dict = eval(self.get_property("limits"))
         self.hutch_temp_addr = self.get_property("hutchTempAddress")
@@ -343,7 +341,7 @@ class EMBLMachineInfo(HardwareObject):
 
     def file_transfer_status_changed(self, status):
         """
-        Updates info about file beeing transfered
+        Updates info about file being transferred
         :param total: int
         :param pending: int
         :param failed: int
@@ -397,9 +395,9 @@ class EMBLMachineInfo(HardwareObject):
 
         if flux_info["measured"] is None:
             self.values_ordered_dict["flux"]["value"] = 0
-            self.values_ordered_dict["flux"][
-                "value_str"
-            ] = "Beamline mode changed\nRemeasure flux!"
+            self.values_ordered_dict["flux"]["value_str"] = (
+                "Beamline mode changed\nRemeasure flux!"
+            )
             self.values_ordered_dict["flux"]["in_range"] = False
         else:
             msg_str = "Flux: %.2E ph/s\n" % flux_info["measured"]["flux"]
@@ -425,7 +423,7 @@ class EMBLMachineInfo(HardwareObject):
         return self.values_ordered_dict
 
     def get_temp_hum_values(self, sleep_time):
-        """Updates temperatur and humidity values"""
+        """Updates temperature and humidity values"""
         while True:
             temp = self.get_external_value(self.hutch_temp_addr)
             hum = self.get_external_value(self.hutch_hum_addr)
@@ -435,9 +433,9 @@ class EMBLMachineInfo(HardwareObject):
                 ):
                     self.hutch_temp = temp
                     self.hutch_hum = hum
-                    self.values_ordered_dict["temp_hum"][
-                        "value"
-                    ] = "%.1f C, %.1f %%" % (temp, hum)
+                    self.values_ordered_dict["temp_hum"]["value"] = (
+                        "%.1f C, %.1f %%" % (temp, hum)
+                    )
                     self.values_ordered_dict["temp_hum"]["in_range"] = (
                         temp < 25 and hum < 60
                     )
@@ -445,8 +443,7 @@ class EMBLMachineInfo(HardwareObject):
             time.sleep(sleep_time)
 
     def get_current(self):
-        """Returns machine current in mA
-        """
+        """Returns machine current in mA"""
         return self.values_ordered_dict["current"]["value"]
 
     def get_current_value(self):
@@ -462,7 +459,7 @@ class EMBLMachineInfo(HardwareObject):
            implementation how to get a value from epics web tool. At first
            web address string is formed and then web page by urllib2
            extracted. Page contains column with records.
-           Then the last value is choosen as the last active value.
+           Then the last value is chosen as the last active value.
 
         :param addr: epics address
         :type addr: str
@@ -552,7 +549,7 @@ class EMBLMachineInfo(HardwareObject):
             return None, None, None
 
     def sizeof_fmt(self, num):
-        """Returns disk space formated in string"""
+        """Returns disk space formatted in string"""
 
         try:
             for x in ["bytes", "KB", "MB", "GB"]:
