@@ -1,5 +1,5 @@
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -39,6 +39,7 @@ from typing import (
 import gevent
 import gevent.event
 import numpy
+from gevent.lock import Semaphore
 from pydantic.v1 import (
     BaseModel,
     Field,
@@ -266,14 +267,18 @@ class GenericDiffractometer(HardwareObject):
         # flag for using sample_centring hwobj or not
         self.use_sample_centring = None
 
+        # Preventing user multiple clicks during manual centring step
+        self.waiting_for_click = None  # None = legacy/no-wait mode, True = waiting, False = manual centring in progress
+        self.click_lock = Semaphore()
+
         # time to delay for state polling for controllers
-        # not updating state inmediately after cmd started
+        # not updating state immediately after cmd started
         self.delay_state_polling = None
 
         self.delay_state_polling = (
             None  # time to delay for state polling for controllers
         )
-        # not updating state inmediately after cmd started
+        # not updating state immediately after cmd started
 
         # Internal values -----------------------------------------------------
         self.ready_event = None
@@ -417,6 +422,16 @@ class GenericDiffractometer(HardwareObject):
                         "valueChanged",
                         self.emit_diffractometer_moved,
                     )
+                    #
+                    # A work-around to make mesh grid 'Rotate to' feature work.
+                    #
+                    # MXCuBE requires that diffractometer HWO have a `self.centringPhi`
+                    # attribute, used to change 'omega' rotation when running
+                    # mesh 'Rotate to' routine.
+                    #
+                    # See https://github.com/mxcube/mxcubecore/issues/1360 for details.
+                    #
+                    self.centringPhi = self.motor_hwobj_dict["phi"]
                 elif motor_name == "zoom":
                     self.connect(
                         temp_motor_hwobj,
@@ -502,7 +517,7 @@ class GenericDiffractometer(HardwareObject):
                 GenericDiffractometer.PHASE_BEAM,
             ]
 
-    # to make it compatibile
+    # to make it compatible
     def __getattr__(self, attr):
         if attr.startswith("__"):
             raise AttributeError(attr)
@@ -522,7 +537,7 @@ class GenericDiffractometer(HardwareObject):
             return HardwareObject.__getattr__(self, attr)
 
     # Contained Objects
-    # NBNB Temp[orary hack - should be cleaned up together with configuration
+    # NBNB Temporary hack - should be cleaned up together with configuration
     @property
     def omega(self):
         """omega motor object
@@ -532,6 +547,24 @@ class GenericDiffractometer(HardwareObject):
         """
         return self.motor_hwobj_dict.get("phi")
 
+    @property
+    def kappa(self):
+        """kappa motor object
+
+        Returns:
+            AbstractActuator
+        """
+        return self.get_object_by_role("kappa")
+
+    @property
+    def kappa_phi(self):
+        """kappa motor object
+
+        Returns:
+            AbstractActuator
+        """
+        return self.get_object_by_role("kappa_phi")
+
     @property
     def centring_x(self):
         """centring_x motor object
@@ -806,7 +839,6 @@ class GenericDiffractometer(HardwareObject):
                 self.emit_centring_failed()
 
     def cancel_centring_method(self, reject=False):
-
         if self.current_centring_procedure is not None:
             try:
                 self.current_centring_procedure.kill()
@@ -832,7 +864,7 @@ class GenericDiffractometer(HardwareObject):
             self.reject_centring()
 
     def start_manual_centring(self, sample_info=None, wait_result=None):
-        self.emit_progress_message("Manual 3 click centring...")
+        self.emit_progress_message(f"{self.CENTRING_METHOD_MANUAL} centring...")
         if self.use_sample_centring:
             self.current_centring_procedure = sample_centring.start(
                 {
@@ -1064,7 +1096,7 @@ class GenericDiffractometer(HardwareObject):
 
         if self.delay_state_polling is not None and self.delay_state_polling > 0:
             # delay polling for state in the
-            # case of controller not reporting MOVING inmediately after cmd
+            # case of controller not reporting MOVING immediately after cmd
             gevent.sleep(self.delay_state_polling)
 
         self.wait_device_ready(timeout)
@@ -1091,14 +1123,45 @@ class GenericDiffractometer(HardwareObject):
                 "Diffractometer: could not center to beam, aborting"
             )
 
-    def image_clicked(self, x, y, xi=None, yi=None):
+    def image_clicked(
+        self, x: float, y: float, xi: float | None = None, yi: float | None = None
+    ):
+        """Handles a user click sent from the frontend during the manual centring.
+
+        This method is called by the backend when the user clicks on the sample
+        image in the frontend.
+
+        The attribute `self.waiting_for_click` controls whether the click should
+        be accepted or ignored:
+          - None: click is accepted (legacy)
+          - True: waiting for a click, accept it and mark it as received
+          - False: already received a click, ignore further clicks
+
+        Args:
+            x: X coordinate of the click.
+            y: Y coordinate of the click.
+            xi: ...
+            yi: ...
+
+        Raises:
+            RuntimeError: If a click is received while a previous one is still being processed.
         """
-        Descript. :
-        """
-        if self.use_sample_centring:
-            sample_centring.user_click(x, y)
-        else:
-            self.user_clicked_event.set((x, y))
+        with self.click_lock:
+            # "waiting for click" logic is not implememted (legacy) or it is actually waiting for a click
+            if self.waiting_for_click is None or self.waiting_for_click:
+                if self.waiting_for_click:
+                    self.waiting_for_click = False
+                if self.use_sample_centring:
+                    sample_centring.user_click(x, y)
+                else:
+                    self.user_clicked_event.set((x, y))
+            # Already received a click, ignore further clicks
+            else:
+                self.log.warning(
+                    "User attempted to click while the previous centring step was still in progress. Click ignored"
+                )
+                err_msg = "Click ignored: a centring step is still being processed. Please wait before clicking again."
+                raise RuntimeError(err_msg)
 
     def accept_centring(self):
         """
