@@ -41,7 +41,6 @@ from py4j import (
     clientserver,
     java_gateway,
 )
-from py4j.protocol import Py4JJavaError
 
 from mxcubecore import HardwareRepository as HWR
 from mxcubecore.BaseHardwareObjects import (
@@ -68,24 +67,6 @@ sys.modules["_socket"] = _origsocket
 del origsocket
 del _origsocket
 
-try:
-    # This file already does the alternative imports plus some tweaking
-    # TODO It ought to be moved out as an accessible Util file, but meanwhile
-    # Here we take care of the case where it is missing.
-    from mxcubecore.dispatcher import dispatcher
-except ImportError:
-    try:
-        from louie import dispatcher
-    except ImportError:
-        from pydispatch import (
-            dispatcher,
-            robustapply,
-            saferef,
-        )
-
-        saferef.safe_ref = saferef.safeRef
-        robustapply.robust_apply = robustapply.robustApply
-
 __copyright__ = """ Copyright © 2016 - 2019 by Global Phasing Ltd. """
 __license__ = "LGPLv3+"
 __author__ = "Rasmus H Fogh"
@@ -99,7 +80,7 @@ class GphlWorkflowConnection(HardwareObject):
     class HOConfig(ConfiguredObject.HOConfig):
         """Temporary replacement for Pydantic class
 
-        Required during transition, as long as we do nto have teh fields defined"""
+        Required during transition, as long as we do not have the fields defined"""
 
         # Defaults - should be replaced by proper Pydantic
         software_paths = {}
@@ -114,7 +95,7 @@ class GphlWorkflowConnection(HardwareObject):
         super().__init__(name)
         # Py4J gateway to external workflow program
         self._gateway = None
-        self.msg_class_imported = False
+        self.jvm_imports_checked = False
 
         # ID for current workflow calculation
         self._enactment_id = None
@@ -239,7 +220,7 @@ class GphlWorkflowConnection(HardwareObject):
             # so we are never in state 'ON'/STANDBY
             raise RuntimeError("Workflow is already running, cannot be started")
 
-        self.msg_class_imported = False
+        self.jvm_imports_checked = False
 
         # Cannot be done in init, where the api.sessions link is not yet ready
         self.config.software_paths["GPHL_WDIR"] = os.path.join(
@@ -473,7 +454,7 @@ class GphlWorkflowConnection(HardwareObject):
         """Receive and process info message from workflow server
         Return goes to server
 
-        NB Callled freom external java) workflow"""
+        NB Called from external java) workflow"""
         xx0 = self._decode_py4j_message(py4j_message)
         message_type = xx0.message_type
         payload = xx0.payload
@@ -493,34 +474,40 @@ class GphlWorkflowConnection(HardwareObject):
         """Receive and process message from workflow server
         Return goes to server
 
-        NB Callled freom external java) workflow"""
+        NB Called from external java) workflow"""
         if self.get_state() is self.STATES.OFF:
             return None
 
-        if not self.msg_class_imported:
-            # Guard agaiunst Java classes being moved to different packages
-            try:
-                msg_class = (
-                    self._gateway.jvm.py4j.reflection.ReflectionUtil.classForName(
-                        "co.gphl.sdcp.astra.service.py4j.Py4jMessage"
-                    )
+        if not self.jvm_imports_checked:
+            # We need to use dir to check for the presence or absence of an imported
+            # class. hasattr/getattr don't do what is needed here, because if the
+            # attribute name is not present java_gateway receives proto.SUCCESS_PACKAGE
+            # from the Java side and instantiates a JavaPackage with the name, even
+            # though no such package exists in the JVM. See:
+            # https://github.com/py4j/py4j/blob/cb9e392d8fc5bec6b99a612e2911017900061628/py4j-python/src/py4j/java_gateway.py#L1748
+            # This looks like a py4j bug on the Java side but needs more investigation.
+
+            # The Py4jMessage class is used as the indicator class here: we assume that
+            # if it has been imported, all other unqualified Java classnames used via
+            # the default JVM view have been imported, otherwise none of them have been
+            # imported and we need to do it here.
+            if "Py4jMessage" not in dir(self._gateway.jvm):
+                for qualified_class_name in (
+                    "co.gphl.sdcp.astra.service.py4j.Py4jMessage",
+                    "co.gphl.beamline.v2_unstable.instrumentation.CentringStatus",
+                    "co.gphl.beamline.v2_unstable.domain_types.CrystalClass",
+                    "co.gphl.beamline.v2_unstable.domain_types.ChemicalElement",
+                    "co.gphl.beamline.v2_unstable.domain_types.AbsorptionEdge",
+                ):
+                    java_gateway.java_import(self._gateway.jvm, qualified_class_name)
+                logging.getLogger("HWR").warning(
+                    "Importing required unqualified class names from the JVM explicitly"
                 )
-                java_gateway.java_import(
-                    self._gateway.jvm, "co.gphl.sdcp.astra.service.py4j.Py4jMessage"
+                logging.getLogger("HWR").warning(
+                    "Please consider upgrading the GPhL workflow application"
                 )
-            except Py4JJavaError:
-                msg_class = (
-                    self._gateway.jvm.py4j.reflection.ReflectionUtil.classForName(
-                        "co.gphl.sdcp.py4j.Py4jMessage"
-                    )
-                )
-                java_gateway.java_import(
-                    self._gateway.jvm, "co.gphl.sdcp.py4j.Py4jMessage"
-                )
-            logging.getLogger("HWR").debug(
-                "GΦL workflow Py4jMessage class is: %s" % msg_class
-            )
-        self.msg_class_imported = True
+
+            self.jvm_imports_checked = True
 
         xx0 = self._decode_py4j_message(py4j_message)
         message_type = xx0.message_type
@@ -941,9 +928,7 @@ class GphlWorkflowConnection(HardwareObject):
         py4j_payload = self._payload_to_java(payload)
 
         try:
-            response = self._gateway.jvm.co.gphl.sdcp.astra.service.py4j.Py4jMessage(
-                py4j_payload, correlation_id
-            )
+            response = self._gateway.jvm.Py4jMessage(py4j_payload, correlation_id)
         except:
             self.abort_workflow(
                 message="Error creating Java message (%s) to send to workflow"
@@ -956,9 +941,7 @@ class GphlWorkflowConnection(HardwareObject):
     def _CentringDone_to_java(self, centringDone):
         jvm = self._gateway.jvm
         return jvm.astra.messagebus.messages.information.CentringDoneImpl(
-            jvm.co.gphl.beamline.v2_unstable.instrumentation.CentringStatus.valueOf(
-                centringDone.status
-            ),
+            jvm.CentringStatus.valueOf(centringDone.status),
             self.to_java_time(centringDone.timestamp),
             self._GoniostatTranslation_to_java(centringDone.goniostatTranslation),
         )
@@ -1031,6 +1014,8 @@ class GphlWorkflowConnection(HardwareObject):
         for item in collectionDone.scanIdMap.items():
             scanIdMap[jvm.java.util.UUID.fromString(conversion.text_type(item[0]))] = (
                 jvm.java.util.UUID.fromString(conversion.text_type(item[1]))
+                if item[1]
+                else None
             )
         return jvm.astra.messagebus.messages.information.CollectionDoneImpl(
             proposalId,
@@ -1058,9 +1043,7 @@ class GphlWorkflowConnection(HardwareObject):
         crystal_classes = selectedLattice.userCrystalClasses
         if crystal_classes:
             ccset = set(
-                jvm.co.gphl.beamline.v2_unstable.domain_types.CrystalClass.fromStringList(
-                    self.toJStringArray(crystal_classes)
-                )
+                jvm.CrystalClass.fromStringList(self.toJStringArray(crystal_classes))
             )
             builder = builder.userCrystalClasses(ccset)
         urlstrings = selectedLattice.referenceReflectionFiles
@@ -1109,9 +1092,7 @@ class GphlWorkflowConnection(HardwareObject):
         crystal_classes = userProvidedInfo.crystalClasses
         if crystal_classes:
             ccset = set(
-                jvm.co.gphl.beamline.v2_unstable.domain_types.CrystalClass.fromStringList(
-                    self.toJStringArray(crystal_classes)
-                )
+                jvm.CrystalClass.fromStringList(self.toJStringArray(crystal_classes))
             )
             builder = builder.crystalClasses(ccset)
         xx0 = userProvidedInfo.spaceGroup
@@ -1138,12 +1119,8 @@ class GphlWorkflowConnection(HardwareObject):
         if anomalousScatterer is None:
             return None
 
-        element = jvm.co.gphl.beamline.v2_unstable.domain_types.ChemicalElement.valueOf(
-            anomalousScatterer.element
-        )
-        edge = jvm.co.gphl.beamline.v2_unstable.domain_types.AbsorptionEdge.valueOf(
-            anomalousScatterer.edge
-        )
+        element = jvm.ChemicalElement.valueOf(anomalousScatterer.element)
+        edge = jvm.AbsorptionEdge.valueOf(anomalousScatterer.edge)
         return jvm.astra.messagebus.messages.domain_types.AnomalousScattererImpl(
             element, edge
         )
