@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -286,7 +286,7 @@ class Harvester(HardwareObject):
         return None
 
     def check_crystal_state(self, crystal_uuid: str) -> Optional[str]:
-        """Check wether if a Crystal is in pending_and_current or not
+        """Check whether if a Crystal is in pending_and_current or not
 
         Args (str) : Crystal uuid
 
