@@ -21,6 +21,7 @@ from mxcubecore.TaskUtils import task
 
 class MiniDiff(HardwareObject):
     MANUAL3CLICK_MODE = "Manual 3-click"
+    CENTRING_METHOD_MANUAL = MANUAL3CLICK_MODE
     C3D_MODE = "Computer automatic"
     # MOVE_TO_BEAM_MODE = "Move to Beam"
 
@@ -244,10 +245,10 @@ class MiniDiff(HardwareObject):
         # Agree on a correct method name, inconsistent arguments for move_to_beam, disabled temporarily
         # self.move_to_coord = self.move_to_beam()
 
-    def set_rotation_axis_position(self, value: float, motor_name="phiz"):
-        self._set_rotation_axis_position(value, motor_name=motor_name)
+    def set_rotation_axis_position(self, value: float):
+        self._set_rotation_axis_position(value, motor_name="phiz")
 
-    def _set_rotation_axis_position(self, value: float, motor_name="phiy"):
+    def _set_rotation_axis_position(self, value: float, motor_name="phiz"):
         logging.getLogger("HWR").info(
             f"Setting rotation axis ({motor_name}) position to {value}"
         )
@@ -455,6 +456,7 @@ class MiniDiff(HardwareObject):
         self.emit("zoomMotorPredefinedPositionChanged", (positionName, offset))
 
     def zoomMotorStateChanged(self, state):
+        HWR.beamline.beam.re_emit_values()
         self.emit("zoomMotorStateChanged", (state,))
         self.emit("minidiffStateChanged", (state,))
 
@@ -1008,10 +1010,11 @@ class MiniDiff(HardwareObject):
             time.sleep(0.1)
 
     def take_snapshot(self, image_path_list: list) -> None:
-        if self.get_current_phase() != "Centring":
-            use_custom_snapshot_routine = self.get_property(
-                "custom_snapshot_script_dir", False
-            )
+        if len(image_path_list) > 0:
+            if self.get_current_phase() != "Centring":
+                use_custom_snapshot_routine = self.get_property(
+                    "custom_snapshot_script_dir", False
+                )
 
             if not use_custom_snapshot_routine:
                 self.set_phase("Centring", wait=True, timeout=200)
@@ -1022,7 +1025,9 @@ class MiniDiff(HardwareObject):
                 f"Taking {snapshot_index + 1} sample snapshot(s)"
             )
             HWR.beamline.sample_view.save_snapshot(path=image_path)
-            self.phiMotor.set_value_relative(90, timeout=5)
+            # do not move 90 degrees if not needed
+            if not self.in_plate_mode() and snapshot_index < len(image_path_list) - 1:
+                self.phiMotor.set_value_relative(90, timeout=5)
 
     def snapshotsDone(self, snapshotsProcedure):
         HWR.beamline.sample_view.camera.forceUpdate = False
