@@ -1,4 +1,4 @@
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -22,7 +22,7 @@ Hardware object handles QGraphicsView and QGraphicsScene with all
 objects and actions necessary for MXCuBE:
 - Creating/removing/editing/drawing of centring points, collection vectors
   and 2D grids
-- Display of beam shape, rotatio axis, scales
+- Display of beam shape, rotation axis, scales
 - Distance, angle and area measurement tools
 - Video handling, scalling and magnification tools
 
@@ -41,12 +41,6 @@ from __future__ import print_function
 import logging
 import math
 import os
-
-try:
-    import cPickle as pickle
-except Exception:
-    import _pickle as pickle
-
 from copy import deepcopy
 from datetime import datetime
 
@@ -60,14 +54,6 @@ from scipy import (
     signal,
 )
 
-try:
-    import lucid2 as lucid
-except ImportError:
-    try:
-        import lucid
-    except ImportError:
-        pass
-
 from mxcubecore import HardwareRepository as HWR
 from mxcubecore.HardwareObjects import QtGraphicsLib as GraphicsLib
 from mxcubecore.HardwareObjects.abstract.AbstractSampleView import AbstractSampleView
@@ -145,6 +131,7 @@ class QtGraphicsManager(AbstractSampleView):
         self.graphics_move_down_item = None
         self.graphics_move_left_item = None
         self.graphics_magnification_item = None
+        self.camera_hwobj = None
 
     def init(self):
         """Main init function. Initiates all graphics items, hwobjs and
@@ -410,7 +397,7 @@ class QtGraphicsManager(AbstractSampleView):
 
         Args:
             mpos_list (list[mpos_list]): List of motor positions
-            screen_coord (tuple(x, y): Screen cordinate for shape
+            screen_coord (tuple(x, y): Screen coordinate for shape
             t (str): Type str for shape, P (Point), L (Line), G (Grid)
 
         Returns:
@@ -1162,14 +1149,14 @@ class QtGraphicsManager(AbstractSampleView):
             qt_import.QApplication.setOverrideCursor(self.cursor)
 
     def get_graphics_view(self):
-        """Rturns current GraphicsView
+        """Returns current GraphicsView
 
         :returns: QGraphicsView
         """
         return self.graphics_view
 
     def get_graphics_camera_frame(self):
-        """Rturns current CameraFrame
+        """Returns current CameraFrame
 
         :returns: GraphicsCameraFrame
         """
@@ -2050,7 +2037,7 @@ class QtGraphicsManager(AbstractSampleView):
             self.graphics_view.scale(view_scale, view_scale)
 
     def set_image_scale(self, image_scale, use_scale=False):
-        """Scales the incomming frame
+        """Scales the incoming frame
 
         :param image_scale: image scale
         :type image_scale: float 0 - 1.0
@@ -2206,7 +2193,7 @@ class QtGraphicsManager(AbstractSampleView):
 
         :param reference: beam centring reference
         :type reference : str. For example "beam" will return the difference
-                          between actual beam positon and beam shape
+                          between actual beam position and beam shape
         """
         beam_shape_dict = self.detect_object_shape()
 
