@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -103,9 +103,9 @@ class AbstractCollect(HardwareObject, object):
 
         undulators = []
         try:
-            for undulator in self["undulators"]:
+            for undulator in self.config.undulators:
                 undulators.append(undulator)
-        except BaseException:
+        except Exception:
             pass
 
         beam_div_hor, beam_div_ver = HWR.beamline.beam.get_beam_divergence()
@@ -351,7 +351,7 @@ class AbstractCollect(HardwareObject, object):
             self.data_collect_task.kill(block=False)
 
     def collection_finished(self):
-        """Collection finished beahviour"""
+        """Collection finished behaviour"""
 
         success_msg = "Data collection successful"
         self.current_dc_parameters["status"] = success_msg
