@@ -1,4 +1,4 @@
-#  Project: MXCuBE
+#  Project name: MXCuBE
 #  https://github.com/mxcube
 #
 #  This file is part of MXCuBE software.
@@ -21,7 +21,7 @@
 
 [Description]
 Plate manipulator hardware object is used to use diffractometer in plate mode.
-It is compatable with md2, md3 diffractometers. Class is based on
+It is compatible with md2, md3 diffractometers. Class is based on
 SampleChanger, so it has all the sample changed functionalities, like
 mount, unmount sample (in this case move to plate position).
 Plate is organized in rows and columns. Each cell (Cell) contains drop (Drop).
@@ -32,9 +32,9 @@ each drop could have several crystals.
 
 [Commands]
 
-[Emited signals]
+[Emitted signals]
 
- - emited signals defined in SampleChanger class
+ - emitted signals defined in SampleChanger class
 
 [Included Hardware Objects]
 -----------------------------------------------------------------------
@@ -46,8 +46,6 @@ each drop could have several crystals.
 import logging
 import time
 
-import gevent
-
 from mxcubecore.HardwareObjects.abstract import AbstractSampleChanger
 from mxcubecore.HardwareObjects.abstract.sample_changer import (
     Container,
@@ -100,7 +98,7 @@ class Xtal(Sample.Sample):
         """
         In this cas we assume a well in the row is a cell
         """
-        return  self.get_cell().get_row_index() + 1
+        return self.get_cell().get_row_index() + 1
 
     @staticmethod
     def _get_xtal_address(drop, index):
@@ -108,7 +106,7 @@ class Xtal(Sample.Sample):
 
     def get_index(self):
         """
-        Descript. : Sample index is calculated relaive to the row (Basket)
+        Descript. : Sample index is calculated relative to the row (Basket)
                     In this case we assume that in drop is one xtal
                     This should be changed to various num of xtals in the drop
         """
@@ -164,7 +162,6 @@ class Drop(Container.Container):
         return sample[0]
 
 
-
 class Cell(Container.Container):
     __TYPE__ = "Cell"
 
@@ -249,7 +246,7 @@ class PlateManipulatorMockup(AbstractSampleChanger.SampleChanger):
         self.update_state(self.STATES.READY)
 
     def _read_state(self):
-        return 'ready'
+        return "ready"
 
     def _ready(self):
         return True
@@ -453,7 +450,9 @@ class PlateManipulatorMockup(AbstractSampleChanger.SampleChanger):
         self._wait_device_ready()
 
     def _load_data(self, barcode):
-        processing_plan = Crims.get_processing_plan(barcode, self.crims_url, self.crims_user_agent, self.harvester_key)
+        processing_plan = Crims.get_processing_plan(
+            barcode, self.crims_url, self.crims_user_agent, self.harvester_key
+        )
 
         if processing_plan is None:
             msg = "No information about plate with barcode %s found in CRIMS" % barcode
@@ -555,8 +554,8 @@ class PlateManipulatorMockup(AbstractSampleChanger.SampleChanger):
         plate_info_dict["num_cols"] = self.num_cols
         plate_info_dict["num_rows"] = self.num_rows
         plate_info_dict["num_drops"] = self.num_drops
-        plate_info_dict["plate_label"] = self.plate_label or  "Demo plate label"
-        plate_info_dict["plate_barcode"] = self.plate_barcode or  ""
+        plate_info_dict["plate_label"] = self.plate_label or "Demo plate label"
+        plate_info_dict["plate_barcode"] = self.plate_barcode or ""
 
         return plate_info_dict
 
